@@ -17,12 +17,14 @@
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 import string
+import re
 
 def check_token(line, token):
     if line[:len(token)] == token:
 	return 1
     return 0
 
+
 # We need to check that the char after the token is space, but I think
 # we can ignore this
 def find_token(lines, token, start, end = 0):
@@ -34,6 +36,7 @@ def find_token(lines, token, start, end = 0):
 	    return i
     return -1
 
+
 def find_token2(lines, token, start, end = 0):
     if end == 0:
 	end = len(lines)
@@ -43,6 +46,7 @@ def find_token2(lines, token, start, end = 0):
 	    return i
     return -1
 
+
 def find_tokens(lines, tokens, start, end = 0):
     if end == 0:
 	end = len(lines)
@@ -53,6 +57,7 @@ def find_tokens(lines, tokens, start, end = 0):
 		return i
     return -1
 
+
 def find_re(lines, rexp, start, end = 0):
     if end == 0:
 	end = len(lines)
@@ -61,6 +66,7 @@ def find_re(lines, rexp, start, end = 0):
 		return i
     return -1
 
+
 def find_token_backwards(lines, token, start):
     m = len(token)
     for i in xrange(start, -1, -1):
@@ -69,6 +75,7 @@ def find_token_backwards(lines, token, start):
 	    return i
     return -1
 
+
 def find_tokens_backwards(lines, tokens, start):
     for i in xrange(start, -1, -1):
 	line = lines[i]
@@ -77,6 +84,7 @@ def find_tokens_backwards(lines, tokens, start):
 		return i
     return -1
 
+
 def get_value(lines, token, start, end = 0):
     i = find_token2(lines, token, start, end)
     if i == -1:
@@ -86,6 +94,7 @@ def get_value(lines, token, start, end = 0):
     else:
         return ""
 
+
 def del_token(lines, token, i, j):
     k = find_token2(lines, token, i, j)
     if k == -1:
@@ -94,22 +103,37 @@ def del_token(lines, token, i, j):
 	del lines[k]
 	return j-1
 
+
 # Finds the paragraph that contains line i.
-def get_paragraph(lines, i):
+def get_paragraph(lines, i, format):
+    if format < 225:
+        begin_layout = "\\layout"
+    else:
+        begin_layout = "\\begin_layout"
     while i != -1:
-	i = find_tokens_backwards(lines, ["\\end_inset", "\\layout"], i)
+	i = find_tokens_backwards(lines, ["\\end_inset", begin_layout], i)
         if i == -1: return -1
-	if check_token(lines[i], "\\layout"):
+	if check_token(lines[i], begin_layout):
 	    return i
 	i = find_beginning_of_inset(lines, i)
+    return -1
+
 
 # Finds the paragraph after the paragraph that contains line i.
-def get_next_paragraph(lines, i):
+def get_next_paragraph(lines, i, format):
+    if format < 225:
+        tokens = ["\\begin_inset", "\\layout", "\\end_float", "\\the_end"]
+    elif format < 236:
+        tokens = ["\\begin_inset", "\\begin_layout", "\\end_float", "\\end_document"]
+    else:
+        tokens = ["\\begin_inset", "\\begin_layout", "\\end_float", "\\end_body", "\\end_document"]
     while i != -1:
-	i = find_tokens(lines, ["\\begin_inset", "\\layout", "\\end_float", "\\the_end"], i)
+	i = find_tokens(lines, tokens, i)
 	if not check_token(lines[i], "\\begin_inset"):
 	    return i
 	i = find_end_of_inset(lines, i)
+    return -1
+
 
 def find_end_of(lines, i, start_token, end_token):
     count = 1
@@ -124,6 +148,7 @@ def find_end_of(lines, i, start_token, end_token):
 	    return i
     return -1
 
+
 # Finds the matching \end_inset
 def find_beginning_of(lines, i, start_token, end_token):
     count = 1
@@ -137,17 +162,21 @@ def find_beginning_of(lines, i, start_token, end_token):
 	    return i
     return -1
 
+
 # Finds the matching \end_inset
 def find_end_of_inset(lines, i):
     return find_end_of(lines, i, "\\begin_inset", "\\end_inset")
 
+
 # Finds the matching \end_inset
 def find_beginning_of_inset(lines, i):
     return find_beginning_of(lines, i, "\\begin_inset", "\\end_inset")
 
+
 def find_end_of_tabular(lines, i):
     return find_end_of(lines, i, "<lyxtabular", "</lyxtabular")
 
+
 def get_tabular_lines(lines, i):
     result = []
     i = i+1
@@ -163,9 +192,11 @@ def get_tabular_lines(lines, i):
 	    i = i+1
     return result
 
+
 def is_nonempty_line(line):
     return line != " "*len(line)
 
+
 def find_nonempty_line(lines, start, end = 0):
     if end == 0:
 	end = len(lines)
@@ -173,14 +204,3 @@ def find_nonempty_line(lines, start, end = 0):
 	if is_nonempty_line(lines[i]):
 	    return i
     return -1
-
-def set_comment(lines, version):
-    lines[0] = "#LyX %s created this file. For more info see http://www.lyx.org/" % version
-    if lines[1][0] == '#':
-	del lines[1]
-
-def set_format(lines, number):
-    if int(number) <= 217:
-        number = float(number)/100
-    i = find_token(lines, "\\lyxformat", 0)
-    lines[i] = "\\lyxformat %s" % number
