@@ -12,10 +12,6 @@
 #ifndef BUFFERVIEW_FUNCS_H
 #define BUFFERVIEW_FUNCS_H
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 #include "LString.h"
 
 class BufferView;
