@@ -11,10 +11,6 @@
 #ifndef DIALOGS_H
 #define DIALOGS_H
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 #include "LString.h"
 
 #include <boost/utility.hpp>
@@ -112,8 +108,6 @@ public:
 	void showFloat(InsetFloat *);
 	///
 	void showWrap(InsetWrap *);
-	/// show all forked child processes
-	void showForks();
 	///
 	void showGraphics(InsetGraphics *);
 	/// show the details of a LyX file include inset
