@@ -13,10 +13,6 @@
 #ifndef PAINTER_H
 #define PAINTER_H
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 #include "LString.h"
 #include "LColor.h"
 
