@@ -1,37 +1,28 @@
 // -*- C++ -*-
-/*
+/**
  * \file ControlError.h
- * This file is part of
- * ======================================================
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
- *           LyX, The Document Processor
+ * \author Angus Leeming
  *
- *           Copyright 2000-2001 The LyX Team.
- *
- * ======================================================
- *
- * \author Angus Leeming, a.leeming@.ac.uk
+ * Full author contact details are available in file CREDITS
  */
 
 #ifndef CONTROLERROR_H
 #define CONTROLERROR_H
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 #include "ControlInset.h"
+#include "insets/inseterror.h" // needed for proper instantiation of GUI<>.
 
 class InsetError;
 
 /** A controller for LaTeX Error dialogs.
  */
-class ControlError : public ControlInset<InsetError, string>
-{
+class ControlError : public ControlInset<InsetError, string> {
 public:
 	///
 	ControlError(LyXView &, Dialogs &);
-
 private:
 	/// not needed.
 	virtual void applyParamsToInset() {}
