@@ -1,21 +1,21 @@
 // -*- C++ -*-
 /**
  * \file ControlPreamble.h
- * Copyright 2001 The LyX Team.
- * See the file COPYING.
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
- * \author Edwin Leuven, leuven@fee.uva.nl
+ * \author Edwin Leuven
+ *
+ * Full author contact details are available in file CREDITS
  */
 
 #ifndef CONTROLPREAMBLE_H
 #define CONTROLPREAMBLE_H
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 #include "ControlDialog_impl.h"
 
+#include "LString.h"
+
 /** A controller for Preamble dialogs.
  */
 class ControlPreamble : public ControlDialogBD {
@@ -24,8 +24,9 @@ public:
 	ControlPreamble(LyXView &, Dialogs &);
 
 	///
-	string & params() const;
-
+	string const & params() const;
+	///
+	void params(string const & newparams);
 private:
 	/// Get changed parameters and Dispatch them to the kernel.
 	virtual void apply();
@@ -35,7 +36,7 @@ private:
 	virtual void clearParams();
 
 	///
-	string * params_;
+	string params_;
 };
 
 #endif // CONTROLPREAMBLE_H
