@@ -12,10 +12,6 @@
 #ifndef CONTROLTEXINFO_H
 #define CONTROLTEXINFO_H
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 #include "ControlDialog_impl.h"
 #include "LString.h"
 
