@@ -12,10 +12,6 @@
 #ifndef QCONTENTPANE_H
 #define QCONTENTPANE_H
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 #ifdef emit
 #undef emit
 #endif
@@ -29,6 +25,10 @@
 
 #include <boost/scoped_ptr.hpp>
 
+#if (defined(Q_WS_X11) && QT_VERSION >= 0x030200)
+#define USE_INPUT_METHODS 1
+#endif
+
 class QWorkArea;
 
 /// for emulating triple click
@@ -101,6 +101,13 @@ protected:
 	void wheelEvent(QWheelEvent * e);
 	/// key press
 	void keyPressEvent(QKeyEvent * e);
+#if USE_INPUT_METHODS
+	/// IM events
+	void imStartEvent(QIMEvent *);
+	void imComposeEvent(QIMEvent *);
+	void imEndEvent(QIMEvent *);
+#endif
+
 public slots:
 	void doubleClickTimeout();
 
