@@ -12,10 +12,6 @@
 #ifndef QERROR_H
 #define QERROR_H
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 #include "Qt2Base.h"
 
 class ControlError;
