@@ -12,10 +12,6 @@
 #ifndef QFLOAT_H
 #define QFLOAT_H
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 #include "Qt2Base.h"
 
 class ControlFloat;
