@@ -13,10 +13,6 @@
 #ifndef QINDEX_H
 #define QINDEX_H
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 #include "Qt2Base.h"
 
 class ControlIndex;
