@@ -12,10 +12,6 @@
 #ifndef QLOG_H
 #define QLOG_H
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 #include "Qt2Base.h"
 
 class ControlLog;
