@@ -12,10 +12,6 @@
 #ifndef QSPELLCHECKERDIALOG_H
 #define QSPELLCHECKERDIALOG_H
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 #include "ui/QSpellcheckerDialogBase.h"
 
 class QSpellchecker;
