@@ -12,10 +12,6 @@
 #ifndef QURL_H
 #define QURL_H
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 #include "Qt2Base.h"
 
 class ControlUrl;
