@@ -1,16 +1,17 @@
+// -*- C++ -*-
 /**
  * \file lengthcombo.h
- * Copyright 2001 the LyX Team
- * Read the file COPYING
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
  * \author John Levon
+ *
+ * Full author contact details are available in file CREDITS
  */
 
 #ifndef LENGTHCOMBO_H
 #define LENGTHCOMBO_H
 
-#include <config.h>
-
 #include <qcombobox.h>
 
 #include "vspace.h"
@@ -25,17 +26,17 @@ public:
 
 	/// set the current item
 	virtual void setCurrentItem(LyXLength::UNIT unit);
-
 	/// get the current item
 	LyXLength::UNIT currentLengthItem() const;
+	/// enable the widget
+	virtual void setEnabled(bool b);
 
 protected slots:
 	virtual void has_activated(int index);
-
 signals:
 	/// the current selection has changed
 	void selectionChanged(LyXLength::UNIT unit);
 
 };
 
-#endif
+#endif // LENGTHCOMBO_H
