@@ -17,10 +17,6 @@
 #ifndef COLOR_H
 #define COLOR_H
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 #include "LString.h"
 
 struct RGBColor;
