@@ -12,10 +12,6 @@
 #ifndef FORMERT_H
 #define FORMERT_H
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 #include "FormBase.h"
 
 class ControlERT;
