@@ -13,11 +13,6 @@
 #ifndef FORMFILEDIALOG_H
 #define FORMFILEDIALOG_H
 
-
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 #include "LString.h"
 
 #include "forms_fwd.h"
