@@ -13,10 +13,6 @@
 #ifndef FORMTABULARCREATE_H
 #define FORMTABULARCREATE_H
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 #include "FormBase.h"
 
 class ControlTabularCreate;
