@@ -15,10 +15,6 @@
 
 #include <config.h>
 
-#ifdef __GNUG__
-#pragma implementation
-#endif
-
 #include <stdlib.h>
 #include "bmtable.h"
 #include XPM_H_LOCATION
