@@ -12,10 +12,6 @@
 #ifndef XFORMS_RESIZE_H
 #define XFORMS_RESIZE_H
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 #include "forms_fwd.h"
 
 /** Ascertains the scaling factor needed to ensure that all labels fit
