@@ -12,10 +12,6 @@
 #ifndef INSET_LATEX_ACCENT_H
 #define INSET_LATEX_ACCENT_H
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 #include "inset.h"
 #include "LString.h"
 
@@ -76,6 +72,8 @@ public:
 	inline bool canDisplay();
 	// should this inset be handled like a normal charater
 	bool isChar() const { return true; }
+	/// is this equivalent to a letter?
+	bool isLetter() const { return candisp; }
 
 	/// all the accent types
 	enum ACCENT_TYPES{
