@@ -1,21 +1,17 @@
 // -*- C++ -*-
-/* This file is part of
- * ======================================================
+/**
+ * \file insetnote.h
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
- *           LyX, The Document Processor
+ * \author Angus Leeming
  *
- *           Copyright 2001 The LyX Team.
- *
- *======================================================
+ * Full author contact details are available in file CREDITS
  */
 
 #ifndef INSETNOTE_H
 #define INSETNOTE_H
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 #include "insetcollapsable.h"
 
 /** The PostIt note inset
@@ -34,7 +30,7 @@ public:
 	///
 	string const editMessage() const;
 	///
-	Inset::Code lyxCode() const { return Inset::IGNORE_CODE; }
+	Inset::Code lyxCode() const { return Inset::NOTE_CODE; }
 	///
 	void write(Buffer const *, std::ostream &) const;
 	///
@@ -44,7 +40,7 @@ public:
 	int linuxdoc(Buffer const *, std::ostream &) const
 		{ return 0; }
 	///
-	int docbook(Buffer const *, std::ostream &) const
+	int docbook(Buffer const *, std::ostream &, bool) const
 		{ return 0; }
 	///
 	int ascii(Buffer const *, std::ostream &, int) const
