@@ -12,10 +12,6 @@
 #ifndef INSETOPTARG_H
 #define INSETOPTARG_H
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 #include "insettext.h"
 #include "insetcollapsable.h"
 
@@ -33,8 +29,6 @@ public:
 	/// make a duplicate of this inset
 	Inset * clone(Buffer const &, bool same_id = false) const;
 
-	/// this inset is editable
-	EDITABLE editable() const { return IS_EDITABLE; }
 	/// code of the inset
 	Inset::Code lyxCode() const { return Inset::OPTARG_CODE; }
 	/// return an message upon editing
