@@ -12,10 +12,6 @@
 #ifndef INSETSECTION_H
 #define INSETSECTION_H
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 #include "LString.h"
 
 #include "insettext.h"
