@@ -13,6 +13,14 @@
 
 #include "LString.h"
 
+// Solaris/x86 version 9 and earlier define these
+#ifdef PC
+#  undef PC
+#endif
+#ifdef SP
+#  undef SP
+#endif
+
 /**
  * LyXLength - Represents latex length measurement
  */
