@@ -1,10 +1,6 @@
 #ifndef MATHAUTOCORRECT_H
 #define MATHAUTOCORRECT_H
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 class MathAtom;
 
 // make "corrections" according to file lib/autocorrect
