@@ -4,10 +4,6 @@
 
 #include "math_gridinset.h"
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 
 class MathCasesInset : public MathGridInset {
 public:
@@ -28,6 +24,8 @@ public:
 	void maplize(MapleStream &) const;
 	///
 	void write(WriteStream & os) const;
+	///
+	void validate(LaTeXFeatures & features) const;
 };
 
 #endif
