@@ -32,11 +32,6 @@ class TextMetricsInfo;
 class TextPainter;
 
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
-
 class MathArray : private std::vector<MathAtom> {
 public:
 	/// re-use inhertited stuff
