@@ -5,10 +5,6 @@
 #include "math_nestinset.h"
 #include "LString.h"
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 /** Decorations and accents over (below) a math object
  *  \author Alejandro Aguilar Sierra
  *
@@ -30,6 +26,8 @@ public:
 	///
 	void metrics(MathMetricsInfo & mi) const;
 	///
+	void validate(LaTeXFeatures & features) const;
+	///
 	void normalize(NormalStream & os) const;
 	///
 	void infoize(std::ostream & os) const;
@@ -43,6 +41,8 @@ private:
 	bool protect() const;
 	/// is it a wide decoration?
 	bool wide() const;
+	/// does this need the amsmath package?
+	bool ams() const;
 
 	///
 	latexkeys const * key_;
