@@ -17,15 +17,19 @@ public:
 	///
 	void symbol(string const &);
 	///
-	void metrics(MathMetricsInfo const & st) const;
+	void metrics(MathMetricsInfo & st) const;
 	///
-	void draw(Painter &, int x, int y) const;
+	void draw(MathPainterInfo &, int x, int y) const;
 
 	///
 	void normalize(NormalStream &) const;
 	///
+	void maximize(MaximaStream &) const;
+	///
 	void maplize(MapleStream &) const;
 	///
+	void mathematicize(MathematicaStream &) const;
+	///
 	void mathmlize(MathMLStream &) const;
 	///
 	void write(WriteStream & os) const;
