@@ -4,10 +4,6 @@
 
 #include "math_gridinset.h"
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 /** This provides an interface between "LyX insets" and "LyX math insets"
  *  \author Andr Pnitz
  *
@@ -114,6 +110,8 @@ private:
 	char const * standardFont() const;
 	/// consistency check
 	void check() const;
+	/// can this change its number of rows?
+	bool rowChangeOK() const;
 	/// can this change its number of cols?
 	bool colChangeOK() const;
 
