@@ -4,11 +4,6 @@
 
 #include "math_gridinset.h"
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
-
 class MathSubstackInset : public MathGridInset {
 public:
 	///
@@ -28,6 +23,8 @@ public:
 	void normalize(NormalStream &) const;
 	///
 	void maplize(MapleStream &) const;
+	///
+	void validate(LaTeXFeatures & features) const;
 };
 
 #endif
