@@ -8,10 +8,6 @@
 #ifndef LYX_FILETOOL_H
 #define LYX_FILETOOL_H
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 #include <vector>
 #include <utility>
 #include "LString.h"
@@ -35,8 +31,8 @@ int DestroyLyXTmpDir(string const & tmpdir);
 /** Find file by searching several directories.
   Uses a string of paths separated by ";"s to find a file to open.
     Can't cope with pathnames with a ';' in them. Returns full path to file.
-    If path entry begins with $$LyX/, use system_lyxdir.
-    If path entry begins with $$User/, use user_lyxdir.
+    If path entry begins with $$LyX/, use system_support.
+    If path entry begins with $$User/, use user_support.
     Example: "$$User/doc;$$LyX/doc".
 */
 string const FileOpenSearch(string const & path, string const & name,
@@ -83,9 +79,9 @@ bool IsSGMLFilename(string const & filename);
 /** Returns the path of a library data file.
   Search the file name.ext in the subdirectory dir of
   \begin{enumerate}
-    \item user_lyxdir
-    \item build_lyxdir (if not empty)
-    \item system_lyxdir
+    \item user_support
+    \item build_support (if not empty)
+    \item system_support
   \end{enumerate}
     The third parameter `ext' is optional.
 */
@@ -100,17 +96,39 @@ string const
 i18nLibFileSearch(string const & dir, string const & name,
 		  string const & ext = string());
 
-/** Takes a command with arguments as input and tries to see whether
-  the command itself can be found in one of the scripts/ directories.
-  If it is found, return the command with fully qualified script name,
-  either return it unchanged */
-string const LibScriptSearch(string const & command);
+/** Takes a command such as "sh $$s/scripts/convertDefault.sh file.in file.out"
+ *  and replaces "$$s/" with the path to the LyX support directory containing
+ *  this script. If the script is not found, "$$s/" is removed. Executing the
+ *  command will still fail, but the error message will make some sort of
+ *  sense ;-)
+ */
+std::string const LibScriptSearch(std::string const & command);
 
 ///
 string const GetEnv(string const & envname);
 
-/// A helper function.
-string const GetEnvPath(string const & name);
+/** Return the contents of the environment variable \c name,
+ *  split using the OS-dependent token separating elements.
+ *  Each element is then passed through os::internal_path to
+ *  guarantee that it is in the form of a unix-stype path.
+ *  If the environment variable is not set, then returns an empty vector.
+ */
+std::vector<string> const getEnvPath(string const & name);
+
+/** Set the contents of the environment variable \c name
+ *  using the paths stored in the \c env vector.
+ *  Each element is passed through os::external_path.
+ */
+void setEnvPath(string const & name, std::vector<string> const & env);
+
+/** Prepend a list of paths to that returned by the environment variable.
+ *  Identical paths occurring later in the list are removed.
+ *  @param name the name of the environment variable.
+ *  @prefix the list of paths in OS-native syntax.
+ *  Eg "/foo/bar:/usr/bin:/usr/local/bin" on *nix,
+ *     "C:\foo\bar;C:\windows" on Windows.
+ */
+void prependEnvPath(string const & name, string const & prefix);
 
 ///
 bool PutEnv(string const & envstr);
@@ -118,6 +136,24 @@ bool PutEnv(string const & envstr);
 ///
 bool PutEnvPath(string const & envstr);
 
+/** @param path a file path in internal_path format. Ie, directories
+ *  are indicated by '/', not by '\'.
+ *
+ *  Manipulates @c path into a form suitable for inclusion in a LaTeX
+ *  document.  
+ *  If @c path contains LaTeX special characters, these are escaped.
+ *  Eg, '~' -> '\string~'
+ *  If @c path contains spaces, then the returned path is enclosed in
+ *  "-quotes. This last fix will lead to successful compiliation of the
+ *  LaTeX file only if a sufficiently modern LaTeX compiler is used.
+ *  If @c exclude_extension is true the extension is left outside the quotes.
+ *  This is needed for pdfeTeX, Version 3.141592-1.21a-2.2 (Web2C 7.5.4)
+ *  (format=pdflatex 2005.4.11) in combination with
+ *  pdftex.def 2002/06/19 v0.03k graphics/color for pdftex:
+ *  It does not recognize the file extension if it is inside the quotes.
+ */
+string const latex_path(string const & path, bool exclude_extension = false);
+
 /// Substitutes active latex characters with underscores in filename
 string const MakeLatexName(string const & file);
 
@@ -211,8 +247,21 @@ void removeAutosaveFile(string const & filename);
 /// read the BoundingBox entry from a ps/eps/pdf-file
 string const readBB_from_PSFile(string const & file);
 
-typedef std::pair<int, string> cmd_ret;
+/** @param filename the file path that is to be mangled.
+ *  @param dir the directory that will contain this file with
+ *  its mangled name. This information is used by the mangling
+ *  algorithm when determining the maximum allowable length of
+ *  the mangled name.
+ *  @returns a mangled representation of the input @c filename.
+ *  Eg C:/foo bar/baz.eps -> 0C__foo_bar_baz.eps
+ *  The integer prefix is used to guarantee that the file name
+ *  is unique.
+ *  Only the file name is returned. It is not prepended with @c dir.
+ */
+string const mangled_filename(string const & filename,
+                              string const & dir = string());
 
+typedef std::pair<int, string> cmd_ret;
 cmd_ret const RunCommand(string const & cmd);
 
 #endif
